@@ -6,10 +6,13 @@ Author: Brian Murray <brian@ubuntu.com>
 
 import errno
 import os
+import re
 
 from apport.hookutils import (
     command_available,
     command_output,
+    recent_syslog,
+    attach_file,
     attach_root_command_outputs)
 
 efiarch = {'amd64': 'x64',
@@ -41,4 +44,15 @@ def add_info(report, ui):
         commands['BootEFIContents'] = 'ls %s' % efiboot
         commands['ShimDiff'] = 'diff %s/shim%s.efi /usr/lib/shim/shim%s.efi.signed' % (efiboot, efiarch[arch], efiarch[arch])
         commands['GrubDiff'] = 'diff %s/grub%s.efi /usr/lib/grub/%s-efi-signed/grub%s.efi.signed' %(efiboot, efiarch[arch], grubarch[arch], efiarch[arch])
-        attach_root_command_outputs(report, commands)
+
+    efivars_dir = '/sys/firmware/efi/efivars'
+    sb_var = os.path.join(efivars_dir,
+                          'SecureBoot-8be4df61-93ca-11d2-aa0d-00e098032b8c')
+    mok_var = os.path.join(efivars_dir,
+                           'MokSBStateRT-605dab50-e046-4300-abb6-3dd810dd8b23')
+
+    attach_file(report, '/proc/sys/kernel/moksbstate_disabled')
+    commands['SecureBoot'] = 'od -An -t u1 %s' % sb_var
+    commands['MokSBStateRT'] = 'od -An -t u1 %s' % mok_var
+    attach_root_command_outputs(report, commands)
+    report['EFITables'] = recent_syslog(re.compile(r'(efi|esrt):|Secure boot'))
